@@ -6,7 +6,7 @@ import re
 def test_syntax_export(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/syntax_error.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/syntax_error.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
