@@ -10,7 +10,7 @@ from rdflib.namespace import Namespace, RDF
 def test_verify_select(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_select.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_select.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -19,7 +19,7 @@ def test_verify_select(caplog):
     assert 'Verification query inline' in logs
     assert 'http://example.com/unlabeled' in logs
 
-    with open('tests/bundle/verify_select_errors.csv') as errors:
+    with open('tests-output/bundle/verify_select_errors.csv') as errors:
         actual = list(row for row in csv.DictReader(errors))
     expected = [{'unlabeled': 'http://example.com/unlabeled'}]
     assert actual == expected
@@ -28,7 +28,7 @@ def test_verify_select(caplog):
 def test_verify_ask(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_ask.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_ask.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -39,7 +39,7 @@ def test_verify_ask(caplog):
 def test_verify_select_multiple(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_select_multiple.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_select_multiple.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -50,12 +50,12 @@ def test_verify_select_multiple(caplog):
     assert re.search(r'Verification query .*verify_domain_select', logs)
     assert 'http://example.com/nonexistent' in logs
 
-    with open('tests/bundle/verify_select_results/verify_label_select_query.csv') as errors:
+    with open('tests-output/bundle/verify_select_results/verify_label_select_query.csv') as errors:
         actual = list(row for row in csv.DictReader(errors))
     expected = [{'unlabeled': 'http://example.com/unlabeled'}]
     assert actual == expected
 
-    with open('tests/bundle/verify_select_results/verify_domain_select_query.csv') as errors:
+    with open('tests-output/bundle/verify_select_results/verify_domain_select_query.csv') as errors:
         actual = list(row for row in csv.DictReader(errors))
     expected = [{'domain': 'http://example.com/nonexistent'}]
     assert actual == expected
@@ -64,7 +64,7 @@ def test_verify_select_multiple(caplog):
 def test_verify_construct(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_construct.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_construct.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -77,7 +77,7 @@ def test_verify_construct(caplog):
 
     validation_graph = Graph()
     validation_graph.parse(
-        'tests/bundle/verify_construct_results/verify_label_construct_query.ttl',
+        'tests-output/bundle/verify_construct_results/verify_label_construct_query.ttl',
         format='turtle')
     sh = Namespace('http://www.w3.org/ns/shacl#')
     errors = [validation_graph.subjects(RDF.type, sh.ValidationResult)]
@@ -85,7 +85,7 @@ def test_verify_construct(caplog):
 
     validation_graph = Graph()
     validation_graph.parse(
-        'tests/bundle/verify_construct_results/verify_domain_construct_query.ttl',
+        'tests-output/bundle/verify_construct_results/verify_domain_construct_query.ttl',
         format='turtle')
     sh = Namespace('http://www.w3.org/ns/shacl#')
     errors = [validation_graph.subjects(RDF.type, sh.ValidationResult)]
@@ -98,7 +98,7 @@ def test_verify_construct(caplog):
 def test_verify_construct_endpoint(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_construct_endpoint.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_construct_endpoint.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -109,7 +109,7 @@ def test_verify_construct_endpoint(caplog):
 
     validation_graph = Graph()
     validation_graph.parse(
-        'tests/bundle/verify_construct_results/verify_fixed_error.ttl',
+        'tests-output/bundle/verify_construct_results/verify_fixed_error.ttl',
         format='turtle')
     sh = Namespace('http://www.w3.org/ns/shacl#')
     errors = [validation_graph.subjects(RDF.type, sh.ValidationResult)]
@@ -119,7 +119,7 @@ def test_verify_construct_endpoint(caplog):
 def test_verify_shacl(caplog):
     with raises(SystemExit) as wrapped_exit:
         onto_tool.main([
-            'bundle', 'tests/bundle/verify_shacl.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/verify_shacl.yaml'
         ])
     assert wrapped_exit.type == SystemExit
     assert wrapped_exit.value.code == 1
@@ -129,7 +129,7 @@ def test_verify_shacl(caplog):
     assert 'skos:prefLabel' in logs
 
     validation_graph = Graph()
-    validation_graph.parse('tests/bundle/verify_shacl_errors.ttl', format='turtle')
+    validation_graph.parse('tests-output/bundle/verify_shacl_errors.ttl', format='turtle')
     sh = Namespace('http://www.w3.org/ns/shacl#')
     errors = [validation_graph.subjects(RDF.type, sh.ValidationResult)]
     assert len(errors) == 1
